@@ -427,8 +427,17 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * {@inheritDoc}
 	 */
 	@Override
-	public boolean notifyMessageReceived(String userIdToNotify,	String messageId, String subject, String messageText) {
+	public boolean notifyMessageReceived(String userIdToNotify,	String messageId, String subject, String messageText,  String ... otherRecipientsFullNames) {
 		String[] optionalParams = {subject};
+		String otherRecipientNames = "";
+		if (otherRecipientsFullNames != null && otherRecipientsFullNames.length > 0) {
+			otherRecipientNames = "<div>This message was also sent to: <ul>";
+			for (int i = 0; i < otherRecipientsFullNames.length; i++) {
+				otherRecipientNames += "<li>" + otherRecipientsFullNames[i] + "</li>";
+			}
+			otherRecipientNames += "</ul></div>";
+		}
+		
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
 				NotificationType.MESSAGE, 
@@ -437,8 +446,9 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 				new Date(),
 				"/group/data-e-infrastructure-gateway/messages", 
 				"sent you a message: " 
-						+ "<div style=\"margin-top: 10px;  margin-bottom: 10px;  margin-left: 50px;  padding-left: 15px;  border-left: 3px solid #ccc; font-style: italic;\">\""
-						+ escapeHtml(messageText) +"\"</div>",
+						+ "<div style=\"margin-top: 10px;  margin-bottom: 10px;  margin-left: 50px;  padding-left: 15px;  border-left: 3px solid #ccc; font-style: italic;\">"
+						+ escapeHtml(messageText) +"</div>"
+								+ otherRecipientNames,
 				false, 
 				aslSession.getUsername(),
 				aslSession.getUserFullName(), 
