@@ -35,8 +35,8 @@ public class EmailPlugin {
 
 	private static final Logger _log = LoggerFactory.getLogger(EmailPlugin.class);
 	protected static final int SECONDS2WAIT = 60;
-	public static final String WRITE_ABOVE_TO_REPLY = "- Write ABOVE THIS LINE to post a reply via email, reply with empty msg to subscribe -";
-
+	public static final String WRITE_ABOVE_MESSAGE_REPLY = "- Write ABOVE THIS LINE to reply via email";
+	public static final String WRITE_ABOVE_TO_REPLY = WRITE_ABOVE_MESSAGE_REPLY + ", reply with empty msg to subscribe -";
 	private static EmailPlugin singleton;
 
 	public static EmailPlugin getInstance() {
@@ -84,6 +84,9 @@ public class EmailPlugin {
 				notification2Save.getType() == NotificationType.OWN_COMMENT) {
 			body.append("<div>").append(WRITE_ABOVE_TO_REPLY).append("</div><br />");
 		}
+		if (notification2Save.getType() == NotificationType.MESSAGE) {
+			body.append("<div>").append(WRITE_ABOVE_MESSAGE_REPLY).append("</div><br />");
+		}
 
 		body.append("<div style=\"color:#000; font-size:13px; font-family:'lucida grande',tahoma,verdana,arial,sans-serif;\">")
 		.append("Dear ").append(userFirstName).append(",")  //dear <user>
@@ -137,6 +140,9 @@ public class EmailPlugin {
 				notification2Save.getType() == NotificationType.OWN_COMMENT) {
 			body.append(WRITE_ABOVE_TO_REPLY).append("\n\n");
 		}
+		if (notification2Save.getType() == NotificationType.MESSAGE) {
+			body.append(WRITE_ABOVE_MESSAGE_REPLY).append("\n\n");
+		}
 
 		body.append("Dear ").append(userFirstName).append(",")  //dear <user>
 		.append("\n").append(sender).append(" ").append(removedMarkup) // has done something
@@ -241,7 +247,11 @@ public class EmailPlugin {
 				notification2Save.getType() == NotificationType.MENTION ||  
 				notification2Save.getType() == NotificationType.OWN_COMMENT) {
 			String[] splits = senderEmail.split("@");
-			senderEmail = splits[0] + "+" + notification2Save.getSubjectid()  + "@" + splits[1];
+			senderEmail = splits[0] + "+" + notification2Save.getSubjectid()  + "$" + AppType.POST + "@" + splits[1];
+		}
+		if (notification2Save.getType() == NotificationType.MESSAGE) {
+			String[] splits = senderEmail.split("@");
+			senderEmail = splits[0] + "+" + notification2Save.getSubjectid()  + "$" + AppType.MSG + "@" + splits[1];
 		}
 		// EMAIL SENDER
 		msg2Return.setHeader("Content-Type", "text/html; charset=UTF-8");
@@ -283,7 +293,7 @@ public class EmailPlugin {
 		case MESSAGE:
 			String messageSubject = (optionalParams != null && optionalParams.length > 0) ? 
 					optionalParams[0] : notification2Save.getSenderFullName()+" sent you a message";
-			return messageSubject;
+					return messageSubject;
 		case WP_FOLDER_ADDEDUSER:
 			return "New user in a shared folder";
 		case WP_FOLDER_REMOVEDUSER:
